package compression

import (
	"bytes"
	"compress/gzip"

	"io/ioutil"
)

func CompressDataGzip(str string) []byte {
	return CompressDataGzipByte([]byte(str))
}

func CompressDataGzipLevel(str string, level int) ([]byte, error) {
	return CompressDataGzipLevelByte([]byte(str), level)
}

func CompressDataGzipByte(data []byte) []byte {
	var b bytes.Buffer
	w := gzip.NewWriter(&b)

	w.Write(data)
	w.Close()
	return b.Bytes()
}

func CompressDataGzipLevelByte(data []byte, level int) ([]byte, error) {
	var b bytes.Buffer
	w := gzip.NewWriter(&b)

	w, err := gzip.NewWriterLevel(&b, level)

	if err != nil {
		return nil, err
	}

	w.Write(data)
	w.Close()
	return b.Bytes(), nil
}

func UnCompressDataGzip(data []byte) ([]byte, error) {
	ucb := bytes.NewReader(data[0:])
	z, err := gzip.NewReader(ucb)
	if err != nil {
		return nil, err
	}
	p, err := ioutil.ReadAll(z)
	if err != nil {
		return nil, err
	}
	z.Close()

	return p, nil
}
