package compression

import (
	"testing"
	"time"
)

func TestCompress(t *testing.T) {

	jsonStr := "{	\"glossary\": {	\"title\": \"example glossary\",	\"GlossDiv\": {	\"title\": \"S\",	\"GlossList\": {	\"GlossEntry\": {	\"ID\": \"SGML\",	\"SortAs\": \"SGML\",	\"GlossTerm\": \"Standard Generalized Markup Language\",	\"Acronym\": \"SGML\",	\"Abbrev\": \"ISO 8879:1986\",	\"GlossDef\": {	\"para\": \"A meta-markup language, used to create markup languages such as DocBook.\",	\"GlossSeeAlso\": [\"GML\", \"XML\"]},\"GlossSee\": \"markup\"}}}}}"

	t.Logf("original length : %d \r\n", len(jsonStr))
	start := time.Now()
	bytes := CompressDataGzip(jsonStr)
	elapsed := time.Since(start)
	t.Logf("compress length : %d \r\n", len(bytes))
	t.Log(elapsed)

}

func TestCompressLevel(t *testing.T) {

	jsonStr := "{	\"glossary\": {	\"title\": \"example glossary\",	\"GlossDiv\": {	\"title\": \"S\",	\"GlossList\": {	\"GlossEntry\": {	\"ID\": \"SGML\",	\"SortAs\": \"SGML\",	\"GlossTerm\": \"Standard Generalized Markup Language\",	\"Acronym\": \"SGML\",	\"Abbrev\": \"ISO 8879:1986\",	\"GlossDef\": {	\"para\": \"A meta-markup language, used to create markup languages such as DocBook.\",	\"GlossSeeAlso\": [\"GML\", \"XML\"]},\"GlossSee\": \"markup\"}}}}}"

	level := 9
	t.Logf("original length : %d \r\n", len(jsonStr))
	start := time.Now()
	bytes, _ := CompressDataGzipLevel(jsonStr, level)
	elapsed := time.Since(start)
	t.Logf("compress length : %d, level %d \r\n", len(bytes), level)
	t.Log(elapsed)

}

func TestUnCompress(t *testing.T) {

	jsonStr := "{	\"glossary\": {	\"title\": \"example glossary\",	\"GlossDiv\": {	\"title\": \"S\",	\"GlossList\": {	\"GlossEntry\": {	\"ID\": \"SGML\",	\"SortAs\": \"SGML\",	\"GlossTerm\": \"Standard Generalized Markup Language\",	\"Acronym\": \"SGML\",	\"Abbrev\": \"ISO 8879:1986\",	\"GlossDef\": {	\"para\": \"A meta-markup language, used to create markup languages such as DocBook.\",	\"GlossSeeAlso\": [\"GML\", \"XML\"]},\"GlossSee\": \"markup\"}}}}}"

	bytes := CompressDataGzip(jsonStr)

	t.Logf("compress length : %d\r\n", len(bytes))
	start := time.Now()
	unComp, err := UnCompressDataGzip(bytes)
	if err != nil {
		t.Log(err)
		return
	}

	elapsed := time.Since(start)
	t.Logf("uncompress length : %d\r\n", len(unComp))
	t.Log(elapsed)

}

func TestUnCompressLevel(t *testing.T) {

	jsonStr := "{	\"glossary\": {	\"title\": \"example glossary\",	\"GlossDiv\": {	\"title\": \"S\",	\"GlossList\": {	\"GlossEntry\": {	\"ID\": \"SGML\",	\"SortAs\": \"SGML\",	\"GlossTerm\": \"Standard Generalized Markup Language\",	\"Acronym\": \"SGML\",	\"Abbrev\": \"ISO 8879:1986\",	\"GlossDef\": {	\"para\": \"A meta-markup language, used to create markup languages such as DocBook.\",	\"GlossSeeAlso\": [\"GML\", \"XML\"]},\"GlossSee\": \"markup\"}}}}}"

	level := 9
	bytes, _ := CompressDataGzipLevel(jsonStr, level)

	t.Logf("compress length : %d, level %d\r\n", len(bytes), level)
	start := time.Now()
	unComp, err := UnCompressDataGzip(bytes)
	if err != nil {
		t.Log(err)
		return
	}

	elapsed := time.Since(start)
	t.Logf("uncompress length : %d\r\n", len(unComp))
	t.Log(elapsed)

}
